==> mastercard_spendcontrols-1.0.0-py2-none-any.whl: mastercardspendcontrols/alertall.py <==
#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from resourceconfig import ResourceConfig

class Alertall(BaseObject):
	"""
	
	"""

	__config = {
		
		"26462d15-0975-4146-a85f-c7f472ce81f2" : OperationConfig("/issuer/v1/card/{uuid}/controls/alerts/all", "delete", [], []),
		
		"19e91880-267b-490c-a916-b792ae1fda84" : OperationConfig("/issuer/v1/card/{uuid}/controls/alerts/all", "query", [], []),
		
		"a5753587-66ef-442d-9465-6e742151f583" : OperationConfig("/issuer/v1/card/{uuid}/controls/alerts/all", "create", [], []),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUI)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext())





	@classmethod
	def deleteById(cls,id,map=None):
		"""
		Delete object of type Alertall by id

		@param str id
		@return Alertall of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""

		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if map:
			if (isinstance(map,RequestMap)):
				mapObj.setAll(map.getObject())
			else:
				mapObj.setAll(map)

		return BaseObject.execute("26462d15-0975-4146-a85f-c7f472ce81f2", Alertall(mapObj))

	def delete(self):
		"""
		Delete object of type Alertall

		@return Alertall of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("26462d15-0975-4146-a85f-c7f472ce81f2", self)








	@classmethod
	def query(cls,criteria):
		"""
		Query objects of type Alertall by id and optional criteria
		@param type criteria
		@return Alertall object representing the response.
		@raise ApiException: raised an exception from the response status
		"""

		return BaseObject.execute("19e91880-267b-490c-a916-b792ae1fda84", Alertall(criteria))

	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type Alertall

		@param Dict mapObj, containing the required parameters to create a new object
		@return Alertall of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("a5753587-66ef-442d-9465-6e742151f583", Alertall(mapObj))

==> mastercard_spendcontrols-1.0.3-py2-none-any.whl: mastercardspendcontrols/alertall.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from resourceconfig import ResourceConfig

class Alertall(BaseObject):
	"""
	
	"""

	__config = {
		
		"af5aa313-e7ea-487d-9337-8851ec1379e1" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/all", "delete", [], []),
		
		"be55097e-3848-4ecb-99ac-b62a19495077" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/all", "query", [], []),
		
		"8c78a1fa-da4f-4443-968a-5878c4d4c232" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/all", "create", [], []),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUID)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative())





	@classmethod
	def deleteById(cls,id,map=None):
		"""
		Delete object of type Alertall by id

		@param str id
		@return Alertall of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""

		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if map:
			if (isinstance(map,RequestMap)):
				mapObj.setAll(map.getObject())
			else:
				mapObj.setAll(map)

		return BaseObject.execute("af5aa313-e7ea-487d-9337-8851ec1379e1", Alertall(mapObj))

	def delete(self):
		"""
		Delete object of type Alertall

		@return Alertall of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("af5aa313-e7ea-487d-9337-8851ec1379e1", self)








	@classmethod
	def query(cls,criteria):
		"""
		Query objects of type Alertall by id and optional criteria
		@param type criteria
		@return Alertall object representing the response.
		@raise ApiException: raised an exception from the response status
		"""

		return BaseObject.execute("be55097e-3848-4ecb-99ac-b62a19495077", Alertall(criteria))

	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type Alertall

		@param Dict mapObj, containing the required parameters to create a new object
		@return Alertall of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("8c78a1fa-da4f-4443-968a-5878c4d4c232", Alertall(mapObj))
